@@ -1,13 +1,15 @@
-# -*- coding: utf8 -*-
+# -*- coding: utf-8 -*-
 
-from ssh_config import ConfigParser
-from exceptions import StormValueError
+from __future__ import print_function
+
+from .ssh_config import ConfigParser
+from .exceptions import StormValueError
 
 from operator import itemgetter
 
 import getpass
 
-__version__ = '0.5.3'
+__version__ = '0.6.1'
 
 
 class Storm(object):
@@ -58,10 +60,12 @@ class Storm(object):
 
         # required for the web api.
         if only_servers:
+            new_config_data = []
             for index, value in enumerate(config_data):
-                print value
-                if value.get('type') and  value.get("type") != 'entry':
-                    del config_data[index]
+                if value.get("type") == 'entry' and value.get("host") != '*':
+                    new_config_data.append(value)
+
+            config_data = new_config_data
 
         if order:
             config_data = sorted(config_data, key=itemgetter("host"))
